package javax.xml.crypto.dsig;

import java.util.Map;
import javax.xml.crypto.MarshalException;
import javax.xml.crypto.XMLCryptoContext;
import javax.xml.crypto.XMLStructure;
import java.security.InvalidAlgorithmParameterException;
import javax.xml.crypto.dsig.spec.TransformParameterSpec;
import java.security.NoSuchProviderException;
import java.util.Iterator;
import java.security.NoSuchAlgorithmException;
import sun.security.jca.GetInstance;
import java.security.Provider;

public abstract class TransformService implements Transform
{
    private String algorithm;
    private String mechanism;
    private Provider provider;
    
    protected TransformService() {
    }
    
    public static TransformService getInstance(String str, String str2) throws NoSuchAlgorithmException {
        if (str2 == null || str == null) {
            throw new NullPointerException();
        }
        boolean n = false;
        if (str2.equals("DOM")) {
            n = true;
        }
        for (Provider.Service s : GetInstance.getServices("TransformService", str)) {
            String attribute = s.getAttribute("MechanismType");
            if ((attribute == null && n) || (attribute != null && attribute.equals(str2))) {
                GetInstance.Instance instance = GetInstance.getInstance(s, null);
                TransformService transformService = (TransformService)instance.impl;
                transformService.algorithm = str;
                transformService.mechanism = str2;
                transformService.provider = instance.provider;
                return transformService;
            }
            continue;
        }
        throw new NoSuchAlgorithmException(str + " algorithm and " + str2 + " mechanism not available");
    }
    
    public static TransformService getInstance(String algorithm, String mechanism, Provider provider) throws NoSuchAlgorithmException {
        if (mechanism == null || algorithm == null || provider == null) {
            throw new NullPointerException();
        }
        boolean n = false;
        if (mechanism.equals("DOM")) {
            n = true;
        }
        Provider.Service service = GetInstance.getService("TransformService", algorithm, provider);
        String attribute = service.getAttribute("MechanismType");
        if ((attribute == null && n) || (attribute != null && attribute.equals(mechanism))) {
            GetInstance.Instance instance = GetInstance.getInstance(service, null);
            TransformService transformService = (TransformService)instance.impl;
            transformService.algorithm = algorithm;
            transformService.mechanism = mechanism;
            transformService.provider = instance.provider;
            return transformService;
        }
        throw new NoSuchAlgorithmException(algorithm + " algorithm and " + mechanism + " mechanism not available");
    }
    
    public static TransformService getInstance(String algorithm, String mechanism, String provider) throws NoSuchAlgorithmException, NoSuchProviderException {
        if (mechanism == null || algorithm == null || provider == null) {
            throw new NullPointerException();
        }
        if (provider.length() == 0) {
            throw new NoSuchProviderException();
        }
        boolean n = false;
        if (mechanism.equals("DOM")) {
            n = true;
        }
        Provider.Service service = GetInstance.getService("TransformService", algorithm, provider);
        String attribute = service.getAttribute("MechanismType");
        if ((attribute == null && n) || (attribute != null && attribute.equals(mechanism))) {
            GetInstance.Instance instance = GetInstance.getInstance(service, null);
            TransformService transformService = (TransformService)instance.impl;
            transformService.algorithm = algorithm;
            transformService.mechanism = mechanism;
            transformService.provider = instance.provider;
            return transformService;
        }
        throw new NoSuchAlgorithmException(algorithm + " algorithm and " + mechanism + " mechanism not available");
    }
    
    public final String getMechanismType() {
        return this.mechanism;
    }
    
    @Override
    public final String getAlgorithm() {
        return this.algorithm;
    }
    
    public final Provider getProvider() {
        return this.provider;
    }
    
    public abstract void init(TransformParameterSpec p0) throws InvalidAlgorithmParameterException;
    
    public abstract void marshalParams(XMLStructure p0, XMLCryptoContext p1) throws MarshalException;
    
    public abstract void init(XMLStructure p0, XMLCryptoContext p1) throws InvalidAlgorithmParameterException;
    
    private static class MechanismMapEntry implements Map.Entry<String, String>
    {
        private final String mechanism;
        private final String algorithm;
        private final String key;
        
        MechanismMapEntry(String s, String mechanism) {
            this.algorithm = s;
            this.mechanism = mechanism;
            this.key = "TransformService." + s + " MechanismType";
        }
        
        @Override
        public boolean equals(Object o) {
            if (!(o instanceof Map.Entry)) {
                return false;
            }
            Map.Entry<Object, Object> entry = (Map.Entry)o;
            return ((this.getKey() != null) ? this.getKey().equals(entry.getKey()) : (entry.getKey() == null)) && ((this.getValue() != null) ? this.getValue().equals(entry.getValue()) : (entry.getValue() == null));
        }
        
        @Override
        public String getKey() {
            return this.key;
        }
        
        @Override
        public String getValue() {
            return this.mechanism;
        }
        
        @Override
        public String setValue(String s) {
            throw new UnsupportedOperationException();
        }
        
        @Override
        public int hashCode() {
            return ((this.getKey() == null) ? 0 : this.getKey().hashCode()) ^ ((this.getValue() == null) ? 0 : this.getValue().hashCode());
        }
    }
}
